---
title: VSCode
---

Tach is installable as a VS Code extension which can be found [here](https://marketplace.visualstudio.com/items?itemName=Gauge.tach).
Instructions for installation and setup are in the extension README and on the [marketplace link](https://marketplace.visualstudio.com/items?itemName=Gauge.tach).

If you have any questions or run into any issues, let us know by either reaching out on [Discord](https://discord.gg/a58vW8dnmw) or submitting a [Github Issue](https://github.com/gauge-sh/tach/issues)!
